#
# spec file for package aaa_base
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           aaa_base
Version:        13.1
Release:        0
Url:            https://github.com/openSUSE/aaa_base
Provides:       aaa_skel = %{version}-%{release}
Provides:       bin
Provides:       bootutls
Provides:       etc
Provides:       skeleng
Provides:       skelger
Obsoletes:      aaa_skel < %{version}
# do not require systemd - aaa_base is in the build environment and we don't want 
# to pull in tons of dependencies
Conflicts:      sysvinit-init
Requires:       /bin/login
Requires:       /bin/mktemp
Requires:       /usr/bin/find
Requires:       /usr/bin/tput
Requires:       /usr/bin/xargs
Requires:       cpio
Requires:       distribution-release
Requires:       filesystem
# for symlink check to /bin/hostname
BuildRequires:  net-tools
BuildRequires:  xz
Recommends:     cron logrotate netcfg udev net-tools aaa_base-extras
PreReq:         /usr/bin/sed /usr/bin/grep /bin/mv /bin/cat /bin/ls /bin/date /usr/bin/cmp /bin/fillup
Summary:        openSUSE Base Package
License:        GPL-2.0+
Group:          System/Fhs
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
# run osc service dr to recreate
Source:         aaa_base-%{version}.tar.xz
#
# Read README.packaging.txt before making any changes to this
# package
#
Source1:        README.packaging.txt
Source99:       aaa_base-rpmlintrc

%description
This package installs several important configuration files and central scripts.

%package extras
Summary:        SUSE Linux Base Package (recommended part)
Group:          System/Fhs
Requires:       %{name} = %{version}
Provides:       aaa_base:/etc/DIR_COLORS

%description extras
The parts of aaa_base that should be installed by default but are not
strictly required to run a system. (Shell aliases, bash completions
and convenience hacks).

%package malloccheck
Summary:        SUSE Linux Base Package (malloc checking)
Group:          System/Fhs
Requires:       %{name} = %{version}

%description malloccheck
This package sets environment variables that enable stricter
malloc checks to catch potential heap corruptions. It's not
installed by default as it may degrade performance.

%prep
%setup -q

%build
make CFLAGS="$RPM_OPT_FLAGS" CC="%{__cc}" %{?_smp_mflags}
if test -d patches/$RPM_ARCH; then
	pushd files
	for file in ../patches/$RPM_ARCH/*; do
		patch -p0 --input=$file
	done
	find -name "*.orig" | xargs -r rm
	popd
fi

%install
#
make DESTDIR=$RPM_BUILD_ROOT install
#
mkdir -p %{buildroot}/etc/sysctl.d
case "$RPM_ARCH" in
	s390*) ;;
	*) rm -f %{buildroot}/usr/lib/sysctl.d/50-default-s390.conf ;;
esac
#
# make sure it does not creep in again
test -d $RPM_BUILD_ROOT/root/.gnupg && exit 1
#
#
# mark these as ghost
for i in passwd group shadow gshadow ; do
  touch $RPM_BUILD_ROOT/var/adm/fillup-templates/$i.aaa_base
done
# we copy some random script there to have a valid ghost - and we can't 
# just touch as long as there is brp-55-check-boot
# we need to fix brp-55 first ;(
#for i in boot.local after.local before.local halt.local ; do
#  cp $RPM_BUILD_ROOT/etc/init.d/boot.localnet $RPM_BUILD_ROOT/etc/init.d/$i
#done

%pre -f aaa_base.pre

%post -f aaa_base.post

%triggerpostun -- aaa_base
if test -f /root/.gnupg/secring.gpg.aaa_save -a ! -f /root/.gnupg/secring.gpg ; then
   mv /root/.gnupg/secring.gpg.aaa_save /root/.gnupg/secring.gpg
fi
rm -f /root/.gnupg/secring.gpg.aaa_save

%files
%defattr(-,root,root)
%doc COPYING
%config(noreplace) %ghost /etc/sysctl.conf
%config /etc/bash.bashrc
%config /etc/csh.cshrc
%config /etc/csh.login
%config /etc/inputrc
%config /etc/mailcap
%config /etc/mime.types
%config /etc/profile
%config /etc/profile.d/alljava.csh
%config /etc/profile.d/alljava.sh
%config /etc/profile.d/csh.ssh
%config /etc/profile.d/csh.utf8
%config /etc/profile.d/lang.csh
%config /etc/profile.d/lang.sh
%config /etc/profile.d/profile.csh
%config /etc/profile.d/profile.sh
%config /etc/profile.d/sh.ssh
%config /etc/profile.d/sh.utf8
%config /etc/profile.d/xdg-environment.csh
%config /etc/profile.d/xdg-environment.sh
%config /etc/rc.splash
%config /etc/rc.status
%config /etc/shells
%config /etc/ttytype
%ghost /var/adm/fillup-templates/passwd.aaa_base
%ghost /var/adm/fillup-templates/group.aaa_base
%ghost /var/adm/fillup-templates/gshadow.aaa_base
%ghost /var/adm/fillup-templates/shadow.aaa_base
#%ghost %attr(0744,root,root) /etc/init.d/after.local
#%ghost %attr(0744,root,root) /etc/init.d/before.local
#%ghost %attr(0744,root,root) /etc/init.d/boot.local
#%ghost %attr(0744,root,root) /etc/init.d/halt.local
# don't forget to also change aaa_base.post, boot.cleanup
# and /etc/permissions!
%ghost %attr(0644,root,root) %verify(not md5 size mtime) /var/log/lastlog
%ghost %attr(0600,root,root) %verify(not md5 size mtime) /var/log/faillog
%ghost %attr(0664,root,utmp) %verify(not md5 size mtime) /var/log/wtmp
%ghost %attr(0600,root,root) %verify(not md5 size mtime) /var/log/btmp
%ghost %attr(0664,root,utmp) %verify(not md5 size mtime) /run/utmp
/etc/init.d/powerfail
/etc/hushlogins
%dir /lib/aaa_base
/lib/aaa_base/convert_sysctl*
%dir /lib/mkinitrd
%dir /lib/mkinitrd/scripts
/lib/mkinitrd/scripts/boot-mtab.sh
/usr/bin/chkconfig
/sbin/chkconfig
/usr/bin/get_kernel_version
/sbin/refresh_initrd
/usr/sbin/refresh_initrd
/sbin/service
/usr/sbin/service
/sbin/smart_agetty
/usr/sbin/smart_agetty
/usr/bin/ChangeSymlinks
/usr/bin/filesize
/usr/bin/mkinfodir
/usr/bin/old
/usr/bin/rpmlocate
/usr/bin/safe-rm
/usr/bin/safe-rmdir
/usr/bin/setJava
/usr/lib/restricted/bin/hostname
/usr/sbin/Check
/usr/sbin/sysconf_addword
/usr/share/man/man1/smart_agetty.1*
/usr/share/man/man5/defaultdomain.5*
/usr/share/man/man8/chkconfig.8*
/usr/share/man/man8/safe-rm.8*
/usr/share/man/man8/safe-rmdir.8*
/usr/share/man/man8/service.8*
/usr/lib/sysctl.d/*.conf
/var/adm/fillup-templates/sysconfig.backup
/var/adm/fillup-templates/sysconfig.boot
/var/adm/fillup-templates/sysconfig.clock
/var/adm/fillup-templates/sysconfig.cron
/var/adm/fillup-templates/sysconfig.language
/var/adm/fillup-templates/sysconfig.news
/var/adm/fillup-templates/sysconfig.proxy
/var/adm/fillup-templates/sysconfig.shutdown
/var/adm/fillup-templates/sysconfig.windowmanager

%files extras
%defattr(-,root,root)
%config(noreplace) /etc/DIR_COLORS
/etc/cron.daily/suse.de-backup-rc.config
/etc/cron.daily/suse.de-backup-rpmdb
/etc/cron.daily/suse.de-check-battery
/etc/cron.daily/suse.de-cron-local
/etc/skel/.emacs
/etc/skel/.inputrc
/etc/java/README
%config /etc/profile.d/complete.bash
%config /etc/profile.d/alias.ash
/etc/profile.d/alias.bash
/etc/profile.d/alias.tcsh
/etc/profile.d/ls.tcsh
/etc/profile.d/ls.bash
/usr/sbin/setDefaultJava
/usr/share/man/man7/init.d.7*
/usr/share/man/man5/route.conf.5*
/usr/share/man/man8/resolv+.8*
/usr/share/man/man8/quick_halt.8*

%files malloccheck
%defattr(-,root,root)
%config /etc/profile.d/malloc-debug.sh
%config /etc/profile.d/malloc-debug.csh

%changelog
